@@ -636,30 +636,34 @@ namespace Breeze
 
             // fill
             QPainter painter(&image);
-            painter.setCompositionMode(QPainter::CompositionMode_Source);
+            painter.setRenderHint( QPainter::Antialiasing, true );
             painter.fillRect( image.rect(), radialGradient);
 
             // contrast pixel
-            painter.setBrush( Qt::NoBrush );
-            painter.setPen( gradientStopColor( g_shadowColor, g_shadowStrength ) );
-            painter.setRenderHints(QPainter::Antialiasing );
-            painter.drawRoundedRect( QRect( g_shadowSize-shadowOffset, g_shadowSize-shadowOffset, shadowOffset, shadowOffset ), 3, 3 );
-            painter.end();
+            QRectF innerRect = QRectF(
+                g_shadowSize - shadowOffset - Metrics::Shadow_Overlap, g_shadowSize - shadowOffset - Metrics::Shadow_Overlap,
+                shadowOffset + 2*Metrics::Shadow_Overlap,shadowOffset + 2*Metrics::Shadow_Overlap );
 
+            painter.setPen( gradientStopColor( g_shadowColor, g_shadowStrength*0.5 ) );
+            painter.setBrush( Qt::NoBrush );
+            painter.drawRoundedRect( innerRect, 2.5, 2.5 );
+
+            // mask out inner rect
+            painter.setPen( Qt::NoPen );
+            painter.setBrush( Qt::black );
+            painter.setCompositionMode(QPainter::CompositionMode_DestinationOut );
+            painter.drawRoundedRect( innerRect, 3.0, 3.0 );
+
+            painter.end();
 
             g_sShadow = QSharedPointer<KDecoration2::DecorationShadow>::create();
             g_sShadow->setPadding( QMargins(
-                g_shadowSize-shadowOffset,
-                g_shadowSize-shadowOffset,
-                g_shadowSize,
-                g_shadowSize ) );
-
-            g_sShadow->setInnerShadowRect(QRect(
-                g_shadowSize-shadowOffset+Metrics::Shadow_Overlap,
-                g_shadowSize-shadowOffset+Metrics::Shadow_Overlap,
-                shadowOffset - 2*Metrics::Shadow_Overlap,
-                shadowOffset - 2*Metrics::Shadow_Overlap ) );
+                g_shadowSize - shadowOffset - Metrics::Shadow_Overlap,
+                g_shadowSize - shadowOffset - Metrics::Shadow_Overlap,
+                g_shadowSize - Metrics::Shadow_Overlap,
+                g_shadowSize - Metrics::Shadow_Overlap ) );
 
+            g_sShadow->setInnerShadowRect(QRect( g_shadowSize, g_shadowSize, 1, 1) );
 
             // assign image
             g_sShadow->setShadow(image);
